"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCandyMachineGpaBuilder = exports.safeFetchAllCandyMachine = exports.fetchAllCandyMachine = exports.safeFetchCandyMachine = exports.fetchCandyMachine = exports.deserializeCandyMachine = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
const types_1 = require("../types");
function deserializeCandyMachine(context, rawAccount) {
    return (0, umi_1.deserializeAccount)(rawAccount, (0, hooked_1.getCandyMachineAccountDataSerializer)(context));
}
exports.deserializeCandyMachine = deserializeCandyMachine;
async function fetchCandyMachine(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_1.assertAccountExists)(maybeAccount, 'CandyMachine');
    return deserializeCandyMachine(context, maybeAccount);
}
exports.fetchCandyMachine = fetchCandyMachine;
async function safeFetchCandyMachine(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists
        ? deserializeCandyMachine(context, maybeAccount)
        : null;
}
exports.safeFetchCandyMachine = safeFetchCandyMachine;
async function fetchAllCandyMachine(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_1.assertAccountExists)(maybeAccount, 'CandyMachine');
        return deserializeCandyMachine(context, maybeAccount);
    });
}
exports.fetchAllCandyMachine = fetchAllCandyMachine;
async function safeFetchAllCandyMachine(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeCandyMachine(context, maybeAccount));
}
exports.safeFetchAllCandyMachine = safeFetchAllCandyMachine;
function getCandyMachineGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplCandyMachineCore', 'CndyV3LdqHUfDLmE5naZjVN8rBZz4tqhdefbAnjHG3JR');
    return (0, umi_1.gpaBuilder)(context, programId)
        .registerFields({
        discriminator: [0, s.array(s.u8(), { size: 8 })],
        version: [8, (0, types_1.getAccountVersionSerializer)(context)],
        tokenStandard: [9, (0, mpl_token_metadata_1.getTokenStandardSerializer)(context)],
        features: [null, s.array(s.u8(), { size: 6 })],
        authority: [null, s.publicKey()],
        mintAuthority: [null, s.publicKey()],
        collectionMint: [null, s.publicKey()],
        itemsRedeemed: [null, s.u64()],
        data: [null, (0, types_1.getCandyMachineDataSerializer)(context)],
    })
        .deserializeUsing((account) => deserializeCandyMachine(context, account))
        .whereField('discriminator', [115, 157, 18, 166, 35, 44, 221, 13]);
}
exports.getCandyMachineGpaBuilder = getCandyMachineGpaBuilder;
//# sourceMappingURL=candyMachine.js.map