"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findFreezeEscrowPda = exports.getFreezeEscrowGpaBuilder = exports.safeFetchAllFreezeEscrow = exports.fetchAllFreezeEscrow = exports.safeFetchFreezeEscrow = exports.fetchFreezeEscrow = exports.deserializeFreezeEscrow = exports.getFreezeEscrowAccountDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getFreezeEscrowAccountDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['candyGuard', s.publicKey()],
        ['candyMachine', s.publicKey()],
        ['frozenCount', s.u64()],
        ['firstMintTime', s.option(s.i64())],
        ['freezePeriod', s.i64()],
        ['destination', s.publicKey()],
        ['authority', s.publicKey()],
    ], { description: 'FreezeEscrow' }), (value) => ({
        ...value,
        discriminator: [100, 4, 61, 102, 0, 123, 141, 187],
    }));
}
exports.getFreezeEscrowAccountDataSerializer = getFreezeEscrowAccountDataSerializer;
function deserializeFreezeEscrow(context, rawAccount) {
    return (0, umi_1.deserializeAccount)(rawAccount, getFreezeEscrowAccountDataSerializer(context));
}
exports.deserializeFreezeEscrow = deserializeFreezeEscrow;
async function fetchFreezeEscrow(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_1.assertAccountExists)(maybeAccount, 'FreezeEscrow');
    return deserializeFreezeEscrow(context, maybeAccount);
}
exports.fetchFreezeEscrow = fetchFreezeEscrow;
async function safeFetchFreezeEscrow(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists
        ? deserializeFreezeEscrow(context, maybeAccount)
        : null;
}
exports.safeFetchFreezeEscrow = safeFetchFreezeEscrow;
async function fetchAllFreezeEscrow(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_1.assertAccountExists)(maybeAccount, 'FreezeEscrow');
        return deserializeFreezeEscrow(context, maybeAccount);
    });
}
exports.fetchAllFreezeEscrow = fetchAllFreezeEscrow;
async function safeFetchAllFreezeEscrow(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeFreezeEscrow(context, maybeAccount));
}
exports.safeFetchAllFreezeEscrow = safeFetchAllFreezeEscrow;
function getFreezeEscrowGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplCandyGuard', 'Guard1JwRhJkVH6XZhzoYxeBVQe872VH6QggF4BWmS9g');
    return (0, umi_1.gpaBuilder)(context, programId)
        .registerFields({
        discriminator: [0, s.array(s.u8(), { size: 8 })],
        candyGuard: [8, s.publicKey()],
        candyMachine: [40, s.publicKey()],
        frozenCount: [72, s.u64()],
        firstMintTime: [80, s.option(s.i64())],
        freezePeriod: [null, s.i64()],
        destination: [null, s.publicKey()],
        authority: [null, s.publicKey()],
    })
        .deserializeUsing((account) => deserializeFreezeEscrow(context, account))
        .whereField('discriminator', [100, 4, 61, 102, 0, 123, 141, 187]);
}
exports.getFreezeEscrowGpaBuilder = getFreezeEscrowGpaBuilder;
function findFreezeEscrowPda(context, seeds) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplCandyGuard', 'Guard1JwRhJkVH6XZhzoYxeBVQe872VH6QggF4BWmS9g');
    return context.eddsa.findPda(programId, [
        s.string({ size: 'variable' }).serialize('freeze_escrow'),
        s.publicKey().serialize(seeds.destination),
        s.publicKey().serialize(seeds.candyGuard),
        s.publicKey().serialize(seeds.candyMachine),
    ]);
}
exports.findFreezeEscrowPda = findFreezeEscrowPda;
//# sourceMappingURL=freezeEscrow.js.map