"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findMintCounterPda = exports.getMintCounterSize = exports.getMintCounterGpaBuilder = exports.safeFetchAllMintCounter = exports.fetchAllMintCounter = exports.safeFetchMintCounter = exports.fetchMintCounter = exports.deserializeMintCounter = exports.getMintCounterAccountDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getMintCounterAccountDataSerializer(context) {
    const s = context.serializer;
    return s.struct([['count', s.u16()]], {
        description: 'MintCounter',
    });
}
exports.getMintCounterAccountDataSerializer = getMintCounterAccountDataSerializer;
function deserializeMintCounter(context, rawAccount) {
    return (0, umi_1.deserializeAccount)(rawAccount, getMintCounterAccountDataSerializer(context));
}
exports.deserializeMintCounter = deserializeMintCounter;
async function fetchMintCounter(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_1.assertAccountExists)(maybeAccount, 'MintCounter');
    return deserializeMintCounter(context, maybeAccount);
}
exports.fetchMintCounter = fetchMintCounter;
async function safeFetchMintCounter(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists
        ? deserializeMintCounter(context, maybeAccount)
        : null;
}
exports.safeFetchMintCounter = safeFetchMintCounter;
async function fetchAllMintCounter(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_1.assertAccountExists)(maybeAccount, 'MintCounter');
        return deserializeMintCounter(context, maybeAccount);
    });
}
exports.fetchAllMintCounter = fetchAllMintCounter;
async function safeFetchAllMintCounter(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeMintCounter(context, maybeAccount));
}
exports.safeFetchAllMintCounter = safeFetchAllMintCounter;
function getMintCounterGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplCandyGuard', 'Guard1JwRhJkVH6XZhzoYxeBVQe872VH6QggF4BWmS9g');
    return (0, umi_1.gpaBuilder)(context, programId)
        .registerFields({ count: [0, s.u16()] })
        .deserializeUsing((account) => deserializeMintCounter(context, account))
        .whereSize(2);
}
exports.getMintCounterGpaBuilder = getMintCounterGpaBuilder;
function getMintCounterSize() {
    return 2;
}
exports.getMintCounterSize = getMintCounterSize;
function findMintCounterPda(context, seeds) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplCandyGuard', 'Guard1JwRhJkVH6XZhzoYxeBVQe872VH6QggF4BWmS9g');
    return context.eddsa.findPda(programId, [
        s.string({ size: 'variable' }).serialize('mint_limit'),
        s.u8().serialize(seeds.id),
        s.publicKey().serialize(seeds.user),
        s.publicKey().serialize(seeds.candyGuard),
        s.publicKey().serialize(seeds.candyMachine),
    ]);
}
exports.findMintCounterPda = findMintCounterPda;
//# sourceMappingURL=mintCounter.js.map