"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCandyGuard = exports.getCreateCandyGuardInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
function getCreateCandyGuardInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['data', s.bytes()],
    ], { description: 'CreateCandyGuardInstructionData' }), (value) => ({
        ...value,
        discriminator: [175, 175, 109, 31, 13, 152, 155, 237],
    }));
}
exports.getCreateCandyGuardInstructionDataSerializer = getCreateCandyGuardInstructionDataSerializer;
function createCandyGuard(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyGuard', 'Guard1JwRhJkVH6XZhzoYxeBVQe872VH6QggF4BWmS9g');
    const baseAccount = input.base;
    const candyGuardAccount = input.candyGuard ??
        (0, hooked_1.findCandyGuardPda)(context, { base: (0, umi_1.publicKey)(baseAccount) });
    const authorityAccount = input.authority ?? context.identity.publicKey;
    const payerAccount = input.payer ?? context.payer;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    keys.push({
        pubkey: candyGuardAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyGuardAccount, true),
    });
    signers.push(baseAccount);
    keys.push({
        pubkey: baseAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(baseAccount, false),
    });
    keys.push({
        pubkey: authorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    const data = getCreateCandyGuardInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.createCandyGuard = createCandyGuard;
//# sourceMappingURL=createCandyGuard.js.map