"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeCandyMachine = exports.getInitializeCandyMachineInstructionDataSerializer = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
const types_1 = require("../types");
function getInitializeCandyMachineInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['itemsAvailable', s.u64()],
        ['symbol', s.string()],
        ['sellerFeeBasisPoints', (0, umi_1.mapAmountSerializer)(s.u16(), '%', 2)],
        ['maxEditionSupply', s.u64()],
        ['isMutable', s.bool()],
        ['creators', s.array((0, types_1.getCreatorSerializer)(context))],
        [
            'configLineSettings',
            s.option((0, types_1.getConfigLineSettingsSerializer)(context)),
        ],
        ['hiddenSettings', s.option((0, types_1.getHiddenSettingsSerializer)(context))],
    ], { description: 'InitializeCandyMachineInstructionData' }), (value) => ({
        ...value,
        discriminator: [175, 175, 109, 31, 13, 152, 155, 237],
        symbol: value.symbol ?? '',
        maxEditionSupply: value.maxEditionSupply ?? 0,
        isMutable: value.isMutable ?? true,
        configLineSettings: value.configLineSettings ?? (0, umi_1.none)(),
        hiddenSettings: value.hiddenSettings ?? (0, umi_1.none)(),
    }));
}
exports.getInitializeCandyMachineInstructionDataSerializer = getInitializeCandyMachineInstructionDataSerializer;
function initializeCandyMachine(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyMachineCore', 'CndyV3LdqHUfDLmE5naZjVN8rBZz4tqhdefbAnjHG3JR');
    const candyMachineAccount = input.candyMachine;
    const authorityPdaAccount = input.authorityPda ??
        (0, hooked_1.findCandyMachineAuthorityPda)(context, {
            candyMachine: (0, umi_1.publicKey)(candyMachineAccount),
        });
    const authorityAccount = input.authority ?? context.identity.publicKey;
    const payerAccount = input.payer ?? context.payer;
    const collectionMintAccount = input.collectionMint;
    const collectionMetadataAccount = input.collectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionMasterEditionAccount = input.collectionMasterEdition ??
        (0, mpl_token_metadata_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionUpdateAuthorityAccount = input.collectionUpdateAuthority;
    const collectionAuthorityRecordAccount = input.collectionAuthorityRecord ??
        (0, mpl_token_metadata_1.findCollectionAuthorityRecordPda)(context, {
            mint: (0, umi_1.publicKey)(collectionMintAccount),
            collectionAuthority: (0, umi_1.publicKey)(authorityPdaAccount),
        });
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    keys.push({
        pubkey: candyMachineAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAccount, true),
    });
    keys.push({
        pubkey: authorityPdaAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityPdaAccount, true),
    });
    keys.push({
        pubkey: authorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, false),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, false),
    });
    keys.push({
        pubkey: collectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMintAccount, false),
    });
    keys.push({
        pubkey: collectionMasterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMasterEditionAccount, false),
    });
    signers.push(collectionUpdateAuthorityAccount);
    keys.push({
        pubkey: collectionUpdateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionUpdateAuthorityAccount, true),
    });
    keys.push({
        pubkey: collectionAuthorityRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionAuthorityRecordAccount, true),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    const data = getInitializeCandyMachineInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.initializeCandyMachine = initializeCandyMachine;
//# sourceMappingURL=initializeCandyMachine.js.map