"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mint = exports.getMintInstructionDataSerializer = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
function getMintInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['mintArgs', s.bytes()],
        ['group', s.option(s.string())],
    ], { description: 'MintInstructionData' }), (value) => ({
        ...value,
        discriminator: [51, 57, 225, 47, 182, 146, 137, 166],
    }));
}
exports.getMintInstructionDataSerializer = getMintInstructionDataSerializer;
function mint(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyGuard', 'Guard1JwRhJkVH6XZhzoYxeBVQe872VH6QggF4BWmS9g');
    const candyMachineAccount = input.candyMachine;
    const candyGuardAccount = input.candyGuard ??
        (0, hooked_1.findCandyGuardPda)(context, { base: (0, umi_1.publicKey)(candyMachineAccount) });
    const candyMachineProgramAccount = input.candyMachineProgram ?? {
        ...context.programs.getPublicKey('mplCandyMachine', 'CndyV3LdqHUfDLmE5naZjVN8rBZz4tqhdefbAnjHG3JR'),
        isWritable: false,
    };
    const candyMachineAuthorityPdaAccount = input.candyMachineAuthorityPda ??
        (0, hooked_1.findCandyMachineAuthorityPda)(context, {
            candyMachine: (0, umi_1.publicKey)(candyMachineAccount),
        });
    const payerAccount = input.payer ?? context.payer;
    const nftMintAccount = input.nftMint;
    const nftMetadataAccount = input.nftMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(nftMintAccount) });
    const nftMintAuthorityAccount = input.nftMintAuthority ?? context.identity;
    const nftMasterEditionAccount = input.nftMasterEdition ??
        (0, mpl_token_metadata_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(nftMintAccount) });
    const collectionMintAccount = input.collectionMint;
    const collectionAuthorityRecordAccount = input.collectionAuthorityRecord ??
        (0, mpl_token_metadata_1.findCollectionAuthorityRecordPda)(context, {
            mint: (0, umi_1.publicKey)(collectionMintAccount),
            collectionAuthority: (0, umi_1.publicKey)(candyMachineAuthorityPdaAccount),
        });
    const collectionMetadataAccount = input.collectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionMasterEditionAccount = input.collectionMasterEdition ??
        (0, mpl_token_metadata_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionUpdateAuthorityAccount = input.collectionUpdateAuthority;
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const recentSlothashesAccount = input.recentSlothashes ??
        (0, umi_1.publicKey)('SysvarS1otHashes111111111111111111111111111');
    const instructionSysvarAccountAccount = input.instructionSysvarAccount ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    keys.push({
        pubkey: candyGuardAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyGuardAccount, false),
    });
    keys.push({
        pubkey: candyMachineProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineProgramAccount, false),
    });
    keys.push({
        pubkey: candyMachineAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAccount, true),
    });
    keys.push({
        pubkey: candyMachineAuthorityPdaAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAuthorityPdaAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: nftMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMetadataAccount, true),
    });
    keys.push({
        pubkey: nftMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMintAccount, true),
    });
    signers.push(nftMintAuthorityAccount);
    keys.push({
        pubkey: nftMintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMintAuthorityAccount, false),
    });
    keys.push({
        pubkey: nftMasterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMasterEditionAccount, true),
    });
    keys.push({
        pubkey: collectionAuthorityRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionAuthorityRecordAccount, false),
    });
    keys.push({
        pubkey: collectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMintAccount, false),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, true),
    });
    keys.push({
        pubkey: collectionMasterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMasterEditionAccount, false),
    });
    keys.push({
        pubkey: collectionUpdateAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionUpdateAuthorityAccount, false),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: recentSlothashesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(recentSlothashesAccount, false),
    });
    keys.push({
        pubkey: instructionSysvarAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(instructionSysvarAccountAccount, false),
    });
    const data = getMintInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.mint = mint;
//# sourceMappingURL=mint.js.map