"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintFromCandyMachineV2 = exports.getMintFromCandyMachineV2InstructionDataSerializer = void 0;
const mpl_essentials_1 = require("@metaplex-foundation/mpl-essentials");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
function getMintFromCandyMachineV2InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.array(s.u8(), { size: 8 })]], { description: 'MintFromCandyMachineV2InstructionData' }), (value) => ({
        ...value,
        discriminator: [120, 121, 23, 146, 173, 110, 199, 205],
    }));
}
exports.getMintFromCandyMachineV2InstructionDataSerializer = getMintFromCandyMachineV2InstructionDataSerializer;
function mintFromCandyMachineV2(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyMachineCore', 'CndyV3LdqHUfDLmE5naZjVN8rBZz4tqhdefbAnjHG3JR');
    const candyMachineAccount = input.candyMachine;
    const authorityPdaAccount = input.authorityPda ??
        (0, hooked_1.findCandyMachineAuthorityPda)(context, {
            candyMachine: (0, umi_1.publicKey)(candyMachineAccount),
        });
    const mintAuthorityAccount = input.mintAuthority;
    const payerAccount = input.payer ?? context.payer;
    const nftOwnerAccount = input.nftOwner;
    const nftMintAccount = input.nftMint;
    const nftMintAuthorityAccount = input.nftMintAuthority ?? context.identity;
    const nftMetadataAccount = input.nftMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(nftMintAccount) });
    const nftMasterEditionAccount = input.nftMasterEdition ??
        (0, mpl_token_metadata_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(nftMintAccount) });
    const tokenAccount = input.token ??
        (0, mpl_essentials_1.findAssociatedTokenPda)(context, {
            mint: (0, umi_1.publicKey)(nftMintAccount),
            owner: (0, umi_1.publicKey)(nftOwnerAccount),
        });
    const tokenRecordAccount = input.tokenRecord ?? {
        ...programId,
        isWritable: false,
    };
    const collectionMintAccount = input.collectionMint;
    const collectionUpdateAuthorityAccount = input.collectionUpdateAuthority;
    const collectionDelegateRecordAccount = input.collectionDelegateRecord ??
        (0, mpl_token_metadata_1.findMetadataDelegateRecordPda)(context, {
            mint: (0, umi_1.publicKey)(collectionMintAccount),
            delegateRole: mpl_token_metadata_1.MetadataDelegateRole.Collection,
            updateAuthority: (0, umi_1.publicKey)(collectionUpdateAuthorityAccount),
            delegate: (0, umi_1.publicKey)(authorityPdaAccount),
        });
    const collectionMetadataAccount = input.collectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionMasterEditionAccount = input.collectionMasterEdition ??
        (0, mpl_token_metadata_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const splTokenProgramAccount = input.splTokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const splAtaProgramAccount = input.splAtaProgram ?? {
        ...context.programs.getPublicKey('splAssociatedToken', 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const recentSlothashesAccount = input.recentSlothashes ??
        (0, umi_1.publicKey)('SysvarS1otHashes111111111111111111111111111');
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    keys.push({
        pubkey: candyMachineAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAccount, true),
    });
    keys.push({
        pubkey: authorityPdaAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityPdaAccount, true),
    });
    signers.push(mintAuthorityAccount);
    keys.push({
        pubkey: mintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAuthorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: nftOwnerAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftOwnerAccount, false),
    });
    if ((0, umi_1.isSigner)(nftMintAccount)) {
        signers.push(nftMintAccount);
    }
    keys.push({
        pubkey: (0, umi_1.publicKey)(nftMintAccount),
        isSigner: (0, umi_1.isSigner)(nftMintAccount),
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMintAccount, true),
    });
    signers.push(nftMintAuthorityAccount);
    keys.push({
        pubkey: nftMintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMintAuthorityAccount, false),
    });
    keys.push({
        pubkey: nftMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMetadataAccount, true),
    });
    keys.push({
        pubkey: nftMasterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(nftMasterEditionAccount, true),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    keys.push({
        pubkey: tokenRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenRecordAccount, true),
    });
    keys.push({
        pubkey: collectionDelegateRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionDelegateRecordAccount, false),
    });
    keys.push({
        pubkey: collectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMintAccount, false),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, true),
    });
    keys.push({
        pubkey: collectionMasterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMasterEditionAccount, false),
    });
    keys.push({
        pubkey: collectionUpdateAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionUpdateAuthorityAccount, false),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: splTokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenProgramAccount, false),
    });
    keys.push({
        pubkey: splAtaProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splAtaProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: recentSlothashesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(recentSlothashesAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    const data = getMintFromCandyMachineV2InstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.mintFromCandyMachineV2 = mintFromCandyMachineV2;
//# sourceMappingURL=mintFromCandyMachineV2.js.map