"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.route = exports.getRouteInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
const types_1 = require("../types");
function getRouteInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['guard', (0, types_1.getGuardTypeSerializer)(context)],
        ['data', s.bytes()],
        ['group', s.option(s.string())],
    ], { description: 'RouteInstructionData' }), (value) => ({
        ...value,
        discriminator: [229, 23, 203, 151, 122, 227, 173, 42],
    }));
}
exports.getRouteInstructionDataSerializer = getRouteInstructionDataSerializer;
function route(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyGuard', 'Guard1JwRhJkVH6XZhzoYxeBVQe872VH6QggF4BWmS9g');
    const candyMachineAccount = input.candyMachine;
    const candyGuardAccount = input.candyGuard ??
        (0, hooked_1.findCandyGuardPda)(context, { base: (0, umi_1.publicKey)(candyMachineAccount) });
    const payerAccount = input.payer ?? context.payer;
    keys.push({
        pubkey: candyGuardAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyGuardAccount, false),
    });
    keys.push({
        pubkey: candyMachineAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    const data = getRouteInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.route = route;
//# sourceMappingURL=route.js.map