"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setCollection = exports.getSetCollectionInstructionDataSerializer = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
function getSetCollectionInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.array(s.u8(), { size: 8 })]], { description: 'SetCollectionInstructionData' }), (value) => ({
        ...value,
        discriminator: [192, 254, 206, 76, 168, 182, 59, 223],
    }));
}
exports.getSetCollectionInstructionDataSerializer = getSetCollectionInstructionDataSerializer;
function setCollection(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyMachineCore', 'CndyV3LdqHUfDLmE5naZjVN8rBZz4tqhdefbAnjHG3JR');
    const candyMachineAccount = input.candyMachine;
    const authorityAccount = input.authority ?? context.identity;
    const authorityPdaAccount = input.authorityPda ??
        (0, hooked_1.findCandyMachineAuthorityPda)(context, {
            candyMachine: (0, umi_1.publicKey)(candyMachineAccount),
        });
    const payerAccount = input.payer ?? context.payer;
    const collectionMintAccount = input.collectionMint;
    const collectionMetadataAccount = input.collectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionAuthorityRecordAccount = input.collectionAuthorityRecord ??
        (0, mpl_token_metadata_1.findCollectionAuthorityRecordPda)(context, {
            mint: (0, umi_1.publicKey)(collectionMintAccount),
            collectionAuthority: (0, umi_1.publicKey)(authorityPdaAccount),
        });
    const newCollectionUpdateAuthorityAccount = input.newCollectionUpdateAuthority;
    const newCollectionMintAccount = input.newCollectionMint;
    const newCollectionMetadataAccount = input.newCollectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(newCollectionMintAccount) });
    const newCollectionMasterEditionAccount = input.newCollectionMasterEdition ??
        (0, mpl_token_metadata_1.findMasterEditionPda)(context, {
            mint: (0, umi_1.publicKey)(newCollectionMintAccount),
        });
    const newCollectionAuthorityRecordAccount = input.newCollectionAuthorityRecord ??
        (0, mpl_token_metadata_1.findCollectionAuthorityRecordPda)(context, {
            mint: (0, umi_1.publicKey)(newCollectionMintAccount),
            collectionAuthority: (0, umi_1.publicKey)(authorityPdaAccount),
        });
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    keys.push({
        pubkey: candyMachineAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    keys.push({
        pubkey: authorityPdaAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityPdaAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, false),
    });
    keys.push({
        pubkey: collectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMintAccount, false),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, false),
    });
    keys.push({
        pubkey: collectionAuthorityRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionAuthorityRecordAccount, true),
    });
    signers.push(newCollectionUpdateAuthorityAccount);
    keys.push({
        pubkey: newCollectionUpdateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionUpdateAuthorityAccount, true),
    });
    keys.push({
        pubkey: newCollectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionMetadataAccount, false),
    });
    keys.push({
        pubkey: newCollectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionMintAccount, false),
    });
    keys.push({
        pubkey: newCollectionMasterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionMasterEditionAccount, false),
    });
    keys.push({
        pubkey: newCollectionAuthorityRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionAuthorityRecordAccount, true),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    const data = getSetCollectionInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.setCollection = setCollection;
//# sourceMappingURL=setCollection.js.map