"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setCollectionV2 = exports.getSetCollectionV2InstructionDataSerializer = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
function getSetCollectionV2InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.array(s.u8(), { size: 8 })]], { description: 'SetCollectionV2InstructionData' }), (value) => ({
        ...value,
        discriminator: [229, 35, 61, 91, 15, 14, 99, 160],
    }));
}
exports.getSetCollectionV2InstructionDataSerializer = getSetCollectionV2InstructionDataSerializer;
function setCollectionV2(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyMachineCore', 'CndyV3LdqHUfDLmE5naZjVN8rBZz4tqhdefbAnjHG3JR');
    const candyMachineAccount = input.candyMachine;
    const authorityAccount = input.authority ?? context.identity;
    const authorityPdaAccount = input.authorityPda ??
        (0, hooked_1.findCandyMachineAuthorityPda)(context, {
            candyMachine: (0, umi_1.publicKey)(candyMachineAccount),
        });
    const payerAccount = input.payer ?? context.payer;
    const collectionUpdateAuthorityAccount = input.collectionUpdateAuthority;
    const collectionMintAccount = input.collectionMint;
    const collectionMetadataAccount = input.collectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionDelegateRecordAccount = input.collectionDelegateRecord ??
        (0, mpl_token_metadata_1.findMetadataDelegateRecordPda)(context, {
            mint: (0, umi_1.publicKey)(collectionMintAccount),
            delegateRole: mpl_token_metadata_1.MetadataDelegateRole.Collection,
            updateAuthority: (0, umi_1.publicKey)(collectionUpdateAuthorityAccount),
            delegate: (0, umi_1.publicKey)(authorityPdaAccount),
        });
    const newCollectionUpdateAuthorityAccount = input.newCollectionUpdateAuthority;
    const newCollectionMintAccount = input.newCollectionMint;
    const newCollectionMetadataAccount = input.newCollectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(newCollectionMintAccount) });
    const newCollectionMasterEditionAccount = input.newCollectionMasterEdition ??
        (0, mpl_token_metadata_1.findMasterEditionPda)(context, {
            mint: (0, umi_1.publicKey)(newCollectionMintAccount),
        });
    const newCollectionDelegateRecordAccount = input.newCollectionDelegateRecord ??
        (0, mpl_token_metadata_1.findMetadataDelegateRecordPda)(context, {
            mint: (0, umi_1.publicKey)(newCollectionMintAccount),
            delegateRole: mpl_token_metadata_1.MetadataDelegateRole.Collection,
            updateAuthority: (0, umi_1.publicKey)(newCollectionUpdateAuthorityAccount),
            delegate: (0, umi_1.publicKey)(authorityPdaAccount),
        });
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    keys.push({
        pubkey: candyMachineAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    keys.push({
        pubkey: authorityPdaAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityPdaAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: collectionUpdateAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionUpdateAuthorityAccount, false),
    });
    keys.push({
        pubkey: collectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMintAccount, false),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, true),
    });
    keys.push({
        pubkey: collectionDelegateRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionDelegateRecordAccount, true),
    });
    signers.push(newCollectionUpdateAuthorityAccount);
    keys.push({
        pubkey: newCollectionUpdateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionUpdateAuthorityAccount, false),
    });
    keys.push({
        pubkey: newCollectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionMintAccount, false),
    });
    keys.push({
        pubkey: newCollectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionMetadataAccount, true),
    });
    keys.push({
        pubkey: newCollectionMasterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionMasterEditionAccount, false),
    });
    keys.push({
        pubkey: newCollectionDelegateRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newCollectionDelegateRecordAccount, true),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    const data = getSetCollectionV2InstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.setCollectionV2 = setCollectionV2;
//# sourceMappingURL=setCollectionV2.js.map