"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setTokenStandard = exports.getSetTokenStandardInstructionDataSerializer = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
function getSetTokenStandardInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['tokenStandard', (0, mpl_token_metadata_1.getTokenStandardSerializer)(context)],
    ], { description: 'SetTokenStandardInstructionData' }), (value) => ({
        ...value,
        discriminator: [147, 212, 106, 195, 30, 170, 209, 128],
    }));
}
exports.getSetTokenStandardInstructionDataSerializer = getSetTokenStandardInstructionDataSerializer;
function setTokenStandard(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplCandyMachineCore', 'CndyV3LdqHUfDLmE5naZjVN8rBZz4tqhdefbAnjHG3JR');
    const candyMachineAccount = input.candyMachine;
    const authorityAccount = input.authority ?? context.identity;
    const authorityPdaAccount = input.authorityPda ??
        (0, hooked_1.findCandyMachineAuthorityPda)(context, {
            candyMachine: (0, umi_1.publicKey)(candyMachineAccount),
        });
    const payerAccount = input.payer ?? context.payer;
    const ruleSetAccount = input.ruleSet ?? { ...programId, isWritable: false };
    const collectionMintAccount = input.collectionMint;
    const collectionUpdateAuthorityAccount = input.collectionUpdateAuthority;
    const collectionDelegateRecordAccount = input.collectionDelegateRecord ??
        (0, mpl_token_metadata_1.findMetadataDelegateRecordPda)(context, {
            mint: (0, umi_1.publicKey)(collectionMintAccount),
            delegateRole: mpl_token_metadata_1.MetadataDelegateRole.Collection,
            updateAuthority: (0, umi_1.publicKey)(collectionUpdateAuthorityAccount),
            delegate: (0, umi_1.publicKey)(authorityPdaAccount),
        });
    const collectionMetadataAccount = input.collectionMetadata ??
        (0, mpl_token_metadata_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(collectionMintAccount) });
    const collectionAuthorityRecordAccount = input.collectionAuthorityRecord ?? {
        ...programId,
        isWritable: false,
    };
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    keys.push({
        pubkey: candyMachineAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(candyMachineAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    keys.push({
        pubkey: authorityPdaAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityPdaAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: ruleSetAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ruleSetAccount, false),
    });
    keys.push({
        pubkey: collectionDelegateRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionDelegateRecordAccount, true),
    });
    keys.push({
        pubkey: collectionMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMintAccount, false),
    });
    keys.push({
        pubkey: collectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionMetadataAccount, true),
    });
    keys.push({
        pubkey: collectionAuthorityRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionAuthorityRecordAccount, true),
    });
    signers.push(collectionUpdateAuthorityAccount);
    keys.push({
        pubkey: collectionUpdateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionUpdateAuthorityAccount, false),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    const data = getSetTokenStandardInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.setTokenStandard = setTokenStandard;
//# sourceMappingURL=setTokenStandard.js.map